MockGatewayWebSocketServer class

A stub implementation of MockGatewayWebSocketServer for platforms without dart:io.

Properties

hashCode int
The hash code for this object.
no setterinherited
pingStream Stream<String>
Stub pingStream getter.
no setter
port int
Stub port getter.
no setter
receivedPings List<String>
Stub receivedPings getter.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wsUri Uri
Stub wsUri getter.
no setter

Methods

broadcast(String message) → void
Stub broadcast method.
broadcastJson(Map<String, dynamic> json) → void
Stub broadcastJson method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() Future<void>
Stub start method.
stop() Future<void>
Stub stop method.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited