MockGatewayHttp class
Helper to build a mock HTTP client that simulates the IBKR Gateway endpoints.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildClient(
) → MockClient -
Builds a
MockClientconfigured with default routes and any custom registered overrides. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerRoute(
String path, Response handler(Request)) → void -
Registers a custom route response handler for the given
path. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited